importance: Extract importance

View source: R/a.R

importanceR Documentation

Extract importance

Description

Extracts importance from the fru model.

Usage

importance(x, ...)

## S3 method for class 'fru'
importance(x, scale = FALSE, ...)

Arguments

x

A model from which importance scores should be extracted; has to hold importance scores (importance=TRUE flag passed to fru).

...

Ignored.

scale

If TRUE, importance scores will be scaled their standard deviation over the ensemble.

Value

A vector of importance scores, in the order and named as columns were in the training data.

Note

Other packages often scale importance by its standard error estimate, thus producing scales importance values square root of tree count times larger than fru. If you get a "non applicable method" error, this method was probably shadowed by other package. Use fru:::importance to call this function explicitly.

Examples

set.seed(1)
data(iris)
fru(iris[,-5],iris[,5],threads=2,importance=TRUE)->model
importance(model)

fru documentation built on Aug. 20, 2026, 9:09 a.m.

Related to importance in fru...