solidify: Solidify a given fru object

View source: R/a.R

solidifyR Documentation

Solidify a given fru object

Description

Forces a model to be solidified, so that it would survive through saving into RDS or sending over a network, etc. The downside is that the forest (and/or OOB scores or importance) will exist twice in the memory, and this process takes some time. The function converts the object in-place, thanks to the semantics of external pointers. No-op when given an object that is already serialised, either by solidify=TRUE flag passed to fru, due to a previous call to solidify or when deserialised.

Usage

solidify(x)

Arguments

x

The fru model object.

Value

Invisibly, the same object as x; the function is called for the side effect of modifying the object.


fru documentation built on Aug. 20, 2026, 9:09 a.m.

Related to solidify in fru...