| importance | R Documentation |
Extracts importance from the fru model.
importance(x, ...)
## S3 method for class 'fru'
importance(x, scale = FALSE, ...)
x |
A model from which importance scores should be extracted; has to hold importance scores ( |
... |
Ignored. |
scale |
If |
A vector of importance scores, in the order and named as columns were in the training data.
Other packages often scale importance by its standard error estimate, thus producing scales importance values square root of tree count times larger than fru.
If you get a "non applicable method" error, this method was probably shadowed by other package.
Use fru:::importance to call this function explicitly.
set.seed(1)
data(iris)
fru(iris[,-5],iris[,5],threads=2,importance=TRUE)->model
importance(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.