| solidify | R Documentation |
Forces a model to be solidified, so that it would survive through saving into RDS or sending over a network, etc.
The downside is that the forest (and/or OOB scores or importance) will exist twice in the memory, and this process takes some time.
The function converts the object in-place, thanks to the semantics of external pointers.
No-op when given an object that is already serialised, either by solidify=TRUE flag passed to fru, due to a previous call to solidify or when deserialised.
solidify(x)
x |
The fru model object. |
Invisibly, the same object as x; the function is called for the side effect of modifying the object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.